Converter
=========

Problematic
-----------

How can we convert some data into something else or something our system understand.

Documentation
-------------

.. automodule:: PyFunceble.converter
   :members:
   :private-members:

:code:`ConverterBase()`
^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.converter.base.ConverterBase
    :members:
    :private-members:

:code:`AdBlock()`
^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.converter.adblock.AdBlock
    :members:
    :private-members:


:code:`Digit2Digits()`
^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.converter.digit2digits.Digit2Digits
    :members:
    :private-members:

:code:`File()`
^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.converter.file.File
    :members:
    :private-members:

:code:`InternalUrl()`
^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.converter.internal_url.InternalUrl
    :members:
    :private-members: